<!DOCTYPE TS><TS>
<context>
    <name>AddMeta</name>
    <message>
        <source>Insert a:</source>
        <translation>Füge ein:</translation>
    </message>
    <message>
        <source>&amp;Marker</source>
        <translation>&amp;Marker</translation>
    </message>
    <message>
        <source>Voice &amp;Track</source>
        <translation>Voice &amp;Track</translation>
    </message>
    <message>
        <source>Log C&amp;hain</source>
        <translation>Log C&amp;hain</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>EditChain</name>
    <message>
        <source>Edit Log Chain</source>
        <translation>Log Chain editieren</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Starte um:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Aktion wenn vorheriges Event noch läuft</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Sofort starten</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Als Nächstes</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Warte bis zu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Übergang</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation>Übergangstyp:</translation>
    </message>
    <message>
        <source>Log Name</source>
        <translation>Logname</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Log Description</source>
        <translation>Logbeschreibung</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
    </message>
</context>
<context>
    <name>EditLog</name>
    <message>
        <source>Edit Log</source>
        <translation>Log editieren</translation>
    </message>
    <message>
        <source>Log Name:</source>
        <translation>Logname</translation>
    </message>
    <message>
        <source>Tracks:</source>
        <translation>Tracks:</translation>
    </message>
    <message>
        <source>Origin:</source>
        <translation>Herkunft:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Service:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Enable AutoRefresh:</source>
        <translation>AutoRefresh einschalten:</translation>
    </message>
    <message>
        <source>Start Date:</source>
        <translation>Startdatum:</translation>
    </message>
    <message>
        <source>End Date:</source>
        <translation>Enddatum:</translation>
    </message>
    <message>
        <source>Start Date Enabled</source>
        <translation>Start Datum ein</translation>
    </message>
    <message>
        <source>End Date Enabled</source>
        <translation>Enddatum an</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation>ÜBERGANG</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CART</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>LÄNGE</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>KÜNSTLER</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>KUNDE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGENTUR</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation>LABEL</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation>QUELLE</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation>LINE ID</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation>ZÄHLER</translation>
    </message>
    <message>
        <source>Insert
Cart</source>
        <translation>Cart
einfügen</translation>
    </message>
    <message>
        <source>Insert
Meta</source>
        <translation>Meta
einfügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>editieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>löschen</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Save
&amp;As</source>
        <translation>Speichern
&amp;Als</translation>
    </message>
    <message>
        <source>&amp;Reports</source>
        <translation>&amp;Reporte</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Invalid Carts</source>
        <translation>Ungültige Carts</translation>
    </message>
    <message>
        <source>This log contains one or more carts
that are invalid for the selected service!</source>
        <translation>Dieses Log enthält einen oder mehrere Carts,
die für den gewählten Service ungültig sind!</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation>Voice Track</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!

Do you still want to save?</source>
        <translation>Dieses Log enthält Carts die für den
ausgewählten Service nicht verfügbar sind!

Wollen Sie trotzdem speichern?</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Log Hinzufügen</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Log existiert</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation>Log existiert bereits!</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDLogEdit</translation>
    </message>
    <message>
        <source>The log has been modified.
Do you want to save your changes?</source>
        <translation>Das Log modifiziert.
Wollen Sie ihre Änderungen speichern?</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!</source>
        <translation>Dieses Log enthält einen oder mehrere Carts,
die für den gewählten Service ungültig sind!</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PLAY</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>STOP</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>ÜBERGANG</translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation>[cart nicht gefunden]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKER</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>TRACK</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation>LOG CHAIN</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LINK</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[trafficimport]</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation>Traffic</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Voice Tracker</source>
        <translation>Voice Tracker</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- ende des logs ---</translation>
    </message>
    <message>
        <source>[INVALID CART]</source>
        <translation>[UNGÜLTIGER CART]</translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation>Nächste Stop:</translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation>Log Ende:</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation>Laufzeit</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation>Ausgewählt:</translation>
    </message>
    <message>
        <source>Delete on</source>
        <translation>Lösche am</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Unable to save log, audio deletion error!</source>
        <translation>Kann Logdatei nicht speichern, Audiolöschfehler!</translation>
    </message>
</context>
<context>
    <name>EditLogLine</name>
    <message>
        <source>Edit Log Entry</source>
        <translation>Logeintrag editieren</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Starte um:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Aktion wenn vorheriges Event noch läuft</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Sofort starten</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Als Nächstes</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Warte bis zu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Übergang</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation>Übergangstyp:</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Cart</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Künstler</translation>
    </message>
    <message>
        <source>Select
Cart</source>
        <translation>Cart
auswählen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
    </message>
    <message>
        <source>Missing Cart</source>
        <translation>Fehlender Cart</translation>
    </message>
    <message>
        <source>You must supply a cart number!</source>
        <translation>Sie müssen eine Cartnummer angeben!</translation>
    </message>
    <message>
        <source>Disabled Cart</source>
        <translation>Abgeschalteter Cart</translation>
    </message>
    <message>
        <source>This cart belongs to a disabled
group for the specified service!</source>
        <translation>Dieser Cart gehört einer abgeschalteten
Gruppe des ausgewählten Service!</translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation>Kein Faden beim Segue Out</translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation>Doppelte Startzeit</translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation>Es existiert bereits ein Event mit dieser Startzeit!</translation>
    </message>
</context>
<context>
    <name>EditMarker</name>
    <message>
        <source>Edit Log Marker</source>
        <translation>Log Marker editieren</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Starte um:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Aktion wenn vorheriges Event noch läuft</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Sofort starten</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Als Nächstes</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Warte bis zu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Übergang</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation>Übergangstyp:</translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Voice Track Marker editieren</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Starte um:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Aktion wenn vorheriges Event noch läuft</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Sofort starten</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Als Nächstes</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Warte bis zu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Übergang</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation>Übergangstyp:</translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation>Ein Log auswählen</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVICE</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation>RDLibrary Reports</translation>
    </message>
    <message>
        <source>Log Listing</source>
        <translation>Log Liste</translation>
    </message>
    <message>
        <source>Log Exception Report</source>
        <translation>Log Fehlerbericht</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>&amp;Generieren</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[keine]</translation>
    </message>
    <message>
        <source>Log Check</source>
        <translation>Log Überprüfung</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation>Keine Fehler gefunden.</translation>
    </message>
    <message>
        <source>Effective Date:</source>
        <translation>Effektives Datum:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>Au&amp;swählen</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogEdit - Host</source>
        <translation type="obsolete">RDLogEdit - Host</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation type="obsolete">Benutzer: [Unbekannt]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kann nicht verbinden</translation>
    </message>
    <message>
        <source>LOG NAME</source>
        <translation>LOGNAME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVICE</translation>
    </message>
    <message>
        <source>MUSIC</source>
        <translation>MUSIK</translation>
    </message>
    <message>
        <source>TRAFFIC</source>
        <translation>TRAFFIC</translation>
    </message>
    <message>
        <source>TRACKS</source>
        <translation>TRACKS</translation>
    </message>
    <message>
        <source>VALID FROM</source>
        <translation>GÜLTIG VON</translation>
    </message>
    <message>
        <source>VALID TO</source>
        <translation>GÜLTIG BIS</translation>
    </message>
    <message>
        <source>AUTO REFRESH</source>
        <translation>AUTO REFRESH</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation>HERKUNFT</translation>
    </message>
    <message>
        <source>LAST LINKED</source>
        <translation>ZULETZT GELINKT</translation>
    </message>
    <message>
        <source>LAST MODIFIED</source>
        <translation>ZULETZT GEÄNDERT</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>Voice
&amp;Tracker</source>
        <translation>Voice
&amp;Tracker</translation>
    </message>
    <message>
        <source>Log
Report</source>
        <translation>Log
Report</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Log Hinzufügen</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Log existiert</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation>Log existiert bereits!</translation>
    </message>
    <message>
        <source>Delete Log</source>
        <translation>Log Löschen</translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Dies löscht ebenfalls die</translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation>Voice Tracks die mit diesem Log verbunden sind.
Fortfahren?</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>Track existiert</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Immer</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDLogEdit</translation>
    </message>
    <message>
        <source>Unable to delete log, audio deletion error!</source>
        <translation>Kann Logdatei nicht löschen, Audiolöschfehler!</translation>
    </message>
    <message>
        <source>RDLogEdit -- Database Skew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This version of RDLogEdit is incompatible with the version installed on the server.
See your system administrator for an update!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VoiceTracker</name>
    <message>
        <source>Voice Tracker</source>
        <translation type="unfinished">Voice Tracker</translation>
    </message>
    <message>
        <source>Edit Cue Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo Segue Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Start Point Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set End Point Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set to Hook Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Previous
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="unfinished">Zeit</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="unfinished">ÜBERGANG</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="unfinished">CART</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="unfinished">GRUPPE</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="unfinished">LÄNGE</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished">TITEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="unfinished">KÜNSTLER</translation>
    </message>
    <message>
        <source>Do Over</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hit Post</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Schliessen</translation>
    </message>
    <message>
        <source>No VoiceTrack Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No voicetracking group has been defined for this service,
therefore only existing transitions will be editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Creation Failure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create new cart for voice track!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished">RDLogEdit</translation>
    </message>
    <message>
        <source>Audio Deletion Error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished">TRACK</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation type="unfinished">Voice Track</translation>
    </message>
    <message>
        <source>Track List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No more tracks!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[end of log]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation type="unfinished">[cart nicht gefunden]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished">MARKER</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation type="unfinished">LOG CHAIN</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished">LINK</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished">[musikimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished">[trafficimport]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished">PLAY</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished">ÜBERGANG</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">STOP</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save segue changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit - Voice Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
